Learn R Programming

data.checker (version 2.0.0)

check_column_contents: Check Column Contents against schema and checks

Description

This function performs checks on the columns of Validator$data to ensure they meet the specified schema conditions and checks.

Usage

check_column_contents(validator)

Value

The updated Validator object with QA entries for each check.

Arguments

validator

A Validator object containing the column names to be checked.