Skip to contents

Check for duplicate rows. Can use subset of columns to check for duplicates if duplicates_cols is specified in the schema. Otherwise, all columns are used for duplicate check.

Usage

check_duplicates(validator)

Arguments

validator

Validator object

Value

The updated validator object with new log entries appended.