Validates data frames against a defined schema. Produces a report of the checks performed and any issues found, with index and entry value where appropriate. Backend checks are performed using pointblank Richard Iannone et al (2025) tools:::Rd_expr_doi("10.32614/CRAN.package.pointblank").
Maintainer: Analysis Standards and Pipelines Team (ONS) ASAP@ons.gov.uk
Other contributors:
Crown Copyright [copyright holder]
Useful links: