Skip to contents

Generate HTML Representation of a Log

Usage

log_html(validator)

Arguments

validator

A Validator object containing a log to be converted into HTML. It is expected to be in a format compatible with log_to_table.

Value

A string containing the HTML representation of the log.