Learn R Programming

data.checker (version 2.0.0)

types_to_classes: Convert complex types to the correct types and classes

Description

This function modifies a schema by converting column types to their corresponding R classes.

Usage

types_to_classes(schema)

Value

The modified schema with updated type and class fields for each column.

Arguments

schema

A list containing a columns element, where each column is a list with a type field.