Learn R Programming

data.checker (version 2.0.0)

add_check: Add a custom check to the validator

Description

This function allows you to add a custom check to the Validatorobject.

Usage

add_check(validator, description, condition)

Value

The updated Validator object with the custom check added.

Arguments

validator

A Validator object to which the custom check will be added.

description

A description of the custom check.

condition

Expression to be evaluated or logical conditions to define the custom check. Optional if outcome is set