Learn R Programming

data.checker (version 2.0.0)

check_duplicates: Check for duplicate rows. Can use subset of columns to check for duplicates if duplicates_cols is specified in the schema. Otherwise, all columns are used for duplicate check.

Description

Check for duplicate rows. Can use subset of columns to check for duplicates if duplicates_cols is specified in the schema. Otherwise, all columns are used for duplicate check.

Usage

check_duplicates(validator)

Value

The updated validator object with new log entries appended.

Arguments

validator

Validator object