Check schema contents against the data frame provided
check_schema_contents_against_df.RdThis function checks that the contents of the schema are consistent with the data frame provided. It checks for unused schema entries, incompatible schema entries, and that any columns specified in the schema are present in the data frame.