This function checks that the contents of the schema are consistent with the data frame provided. It checks for unused schema entries, incompatible schema entries, and that any columns specified in the schema are present in the data frame.
check_schema_contents_against_df(validator)The updated Validator object with QA entries added for any issues found in the schema.
A Validator object containing the data and schema to check against.