This function exports the log of a Validator object to a file in the specified format.
# S3 method for Validator
export(object, file, format = c("yaml", "json", "html", "csv"), ...)Writes the log to the specified file. No value is returned.
A Validator object containing the log to be exported.
A string specifying the file path where the log will be exported. The file extension must match the specified format.
A string specifying the format of the output file.
Supported formats are "yaml", "json", "html", and "csv".
Additional arguments passed to specific methods.