This function raises errors or warnings if any checks flagged as error or warnings fail.
hard_checks_status(validator, hard_check)Warning if there are any warnings or errors in the log when hard_check is FALSE.
Error if there are any errors and hard_check is TRUE.
A Validator object to check the log.
A logical value indicating whether to perform hard checks (default is TRUE).