log_html.Rd
Generate HTML Representation of a Log
log_html(validator)
A Validator object containing a log to be converted into HTML. It is expected to be in a format compatible with log_to_table.
Validator
log_to_table
A string containing the HTML representation of the log.