Learn R Programming

data.checker (version 2.0.0)

log_html: Generate HTML Representation of a Log

Description

Generate HTML Representation of a Log

Usage

log_html(validator)

Value

A string containing the HTML representation of the log.

Arguments

validator

A Validator object containing a log to be converted into HTML. It is expected to be in a format compatible with log_to_table.