This function extracts validation results from a pointblank agent and appends them to the validator's log.
log_pointblank_outcomes(validator)The updated validator list with new log entries appended.
A list containing a pointblank agent and a log. The agent should have a validation_set from a pointblank interrogation.
Each entry in the log will contain the timestamp, description, outcome, failing row indices, number of failures, and entry type for each validation step.