print.Validator: Print Validator Log
Description
This function prints the log of a Validator object in a markdown table format.
Usage
# S3 method for Validator
print(x, ...)
Value
A markdown-formatted table of the validator log.
Arguments
- x
A Validator object containing a log to be printed.
- ...
Additional arguments passed to specific methods.