powered by
This function modifies a schema by converting column types to their corresponding R classes.
types_to_classes(schema)
The modified schema with updated type and class fields for each column.
type
class
A list containing a columns element, where each column is a list with a type field.
columns