Validate date formats in the schema This function checks that any date formats specified in the schema are valid and can be parsed correctly.
validate_and_convert_date_formats.RdValidate date formats in the schema This function checks that any date formats specified in the schema are valid and can be parsed correctly.